import sys
import os
from tempfile import NamedTemporaryFile
from zipfile import PyZipFile

BASE_DIR = os.path.dirname(os.path.dirname(__file__))
__is_zip = None

def is_zip ():
    """Tests if we are executing in a zip file."""
    global __is_zip
    
    if __is_zip is None:
        try:
            with PyZipFile(sys.argv[0]):
                __is_zip = True
        except Exception:
            __is_zip = False

    return __is_zip

def extract_to_temp_directory (path):
    """If we are in a zip file, extract the specified entry to a named temporary file."""
    with open_entry(path) as entry:
        temp_file = NamedTemporaryFile()
        temp_file.write(entry.read())
        return temp_file

def open_entry_as_file (path):
    """If we are in a zip, extract the specified entry to a named temporary file. If not, open the entry as a file."""
    if is_zip():
        return extract_to_temp_directory(path)
    else:
        return open_entry(path)

def open_entry (path, mode="r"):
    """If we are in a zip, open and return the zip entry. If not, open the entry as a file."""
    if is_zip():
        with PyZipFile(sys.argv[0]) as zip:
            return zip.open(path, mode[0])
    else:
        return open(os.path.join(BASE_DIR, path), mode)