from urllib.request import build_opener, Request, HTTPHandler
from urllib.error import HTTPError
import json

JSON_TYPE = "application/json"

class Cranium (object):
    def __init__ (self, url, token=None):
        self.url = url
        self.token = token
        self.__opener = build_opener(HTTPHandler)
    
    def info (self):
        return self.__request("/info")
    
    def client_info (self):
        return self.__request("/clientInfo")
    
    def get_unit (self, unit_id):
        return self.__request("/units/{}".format(unit_id))
    
    def get_user (self, user_id):
        return self.__request("/users/{}".format(user_id))
    
    def add_unit (self, unit_data, unit_id=None):
        return self.__request("/units/{}".format(unit_id if unit_id else ""), data=unit_data)
    
    def add_unit_token (self, unit_id):
        return self.__request("/units/{}/tokens".format(unit_id), verb="POST")
    
    def remove_unit (self, unit_id):
        return self.__request("/units/{}".format(unit_id), verb="DELETE")

    def activate_unit (self, unit_id, activation_request):
        return self.__request("/units/{}/activation".format(unit_id), data=activation_request, headers={
            "Content-Type": "application/xml"
        })
    
    def deactivate_unit (self, unit_id, deactivation_request):
        return self.__request("/units/{}/activation".format(unit_id), data=deactivation_request, headers={
            "Content-Type": "application/xml"
        })
    
    def __request (self, url, verb=None, data=None, headers=None):
        if not (url.startswith("http://") or url.startswith("https://")):
            if self.url.endswith("/"):
                url = url[1:]
            url = "{}{}".format(self.url, url)
        
        headers = headers or {}
        if self.token:
            headers["Authorization"] = "bearer {}".format(self.token)
        
        # By default assume data is JSON. We can specify an alternative type
        # to override this behavior.
        if not data is None and headers.get("Content-Type", JSON_TYPE) == JSON_TYPE:
            data = json.dumps(data)
            headers["Content-Type"] = JSON_TYPE
        
        if not verb:
            verb = "POST" if data else "GET"
        
        request = Request(url=url, headers=headers, data=data.encode() if data else None)
        request.get_method = lambda: verb # see http://stackoverflow.com/a/111988

        try:
            return json.loads(self.__opener.open(request).read().decode())
        except HTTPError as err:
            if err.code == 307:
                return self.__request(err.info()["Location"], verb=verb, data=data, headers=headers)
            raise err