import os
import json
import inspect
from subprocess import check_output, CalledProcessError
import string
import random

def is_root ():
    return os.geteuid() == 0

def is_systemd ():
    try:
        return check_output(["which", "systemctl"]).strip() != ""
    except CalledProcessError:
        return False

def parse_add_remove_features (features=None):
    add_features = []
    remove_features = []
    
    if features:
        for feature in features:
            if feature[0] in ["!", "-"]:
                remove_features.append(feature[1:])
            else:
                add_features.append(feature)

    return (add_features, remove_features)

def resolve_add_remove_features (available_features, selected_features, default_features):
    (add_features, remove_features) = parse_add_remove_features(selected_features)
    if selected_features is None or (len(add_features) == 0 and len(remove_features) > 0):
        add_features = default_features
    add_features = [available_features[feature] for feature in add_features if not feature in remove_features]
    remove_features = [available_features[feature] for feature in remove_features]
    return (add_features, remove_features)

# http://stackoverflow.com/a/35483750
class ObjectEncoder (json.JSONEncoder):
    def default (self, obj):
        if hasattr(obj, "to_json"):
            return self.default(obj.to_json())
        elif hasattr(obj, "__dict__"):
            d = dict(
                (key, value)
                for key, value in inspect.getmembers(obj)
                if not key.startswith("__")
                and not inspect.isabstract(value)
                and not inspect.isbuiltin(value)
                and not inspect.isfunction(value)
                and not inspect.isgenerator(value)
                and not inspect.isgeneratorfunction(value)
                and not inspect.ismethod(value)
                and not inspect.ismethoddescriptor(value)
                and not inspect.isroutine(value)
            )
            return self.default(d)
        return obj

def random_string (size=6, chars=string.ascii_uppercase + string.digits):
    return "".join(random.choice(chars) for _ in range(size))