import logging
from urllib.error import HTTPError

from ..registration import get_full_repo_url, DEFAULT_REPO_URL, discover_cranium

logger = logging.getLogger(__name__)

def __call__ (config):
    cranium_url = config.registration_url if config.registration_url else (get_full_repo_url(config.repo) if config.repo else DEFAULT_REPO_URL)
    cranium = discover_cranium(cranium_url)
    if not cranium:
        logger.warn("Could not detect lemonade stand instance at %s", cranium_url)
        return {"valid": False}

    cranium.token = config.key
    user_details = None
    try:
        user_details = cranium.get_user("me")
        if not user_details:
            user_details = {"valid": False}
    except HTTPError as error:
        if error.code == 404:
            user_details = {"valid": False}
        else:
            raise error

    logger.info("Valid: %s", user_details["valid"])
    return {"valid": user_details["valid"]}