import logging

from ..database import get_database
from ..capturecast import CaptureCast
from ..context import Context

logger = logging.getLogger(__name__)

def __call__ (config):
    context = Context(config, logger)
    capturecast = CaptureCast(context)
    
    database = get_database(context, config.database) if config.database else capturecast.get_database()
    if database:
        logger.info("Installing {} database and configuring for user {}\n".format(database.config["type"], database.config["user"]))
        database.install()
        
        if not database.validate():
            raise Exception("Failed to set up database")
        
        conf = capturecast.get_settings() or {}
        conf["database-connection"] = database.get_connection_string()
        capturecast.save_settings(conf)