import logging

from ..config import options, defaults
from ..context import Context
from ..helpers import resolve_add_remove_features

logger = logging.getLogger(__name__)

def __call__ (config):
    context = Context(config, logger)
    
    # install user-selected features
    (add_features, remove_features) = resolve_add_remove_features(
        available_features = options["features"],
        selected_features = context.config.features,
        default_features = defaults["features"]
    )
    
    logger.info("Installing Features: {}".format(", ".join([feature["title"] for feature in add_features])))
    context.install(*[feature["packages"] for feature in add_features])

    if len(remove_features) > 0:
        logger.info("Removing Features: {}".format(", ".join([feature["title"] for feature in remove_features])))
        context.remove(*[feature["packages"] for feature in remove_features])
    
    # install user-selected publishers
    (add_publishers, remove_publishers) = resolve_add_remove_features(
        available_features = options["publishers"],
        selected_features = context.config.publishers,
        default_features = defaults["publishers"]
    )
    
    logger.info("Installing Publishers: {}".format(", ".join([publisher["title"] for publisher in add_publishers])))
    context.install(*[publisher["packages"] for publisher in add_publishers if not publisher in remove_publishers])

    if len(remove_publishers) > 0:
        logger.info("Removing Publishers: {}".format(", ".join([publisher["title"] for publisher in remove_publishers])))
        context.remove(*[publisher["packages"] for publisher in remove_publishers])