import logging

from ..config import options, defaults
from ..context import Context
from ..helpers import resolve_add_remove_features

logger = logging.getLogger(__name__)

CATTURA_PLATFORM_PACKAGE = "cattura-minimal-distribution"

def __call__ (config):
    context = Context(config, logger)
    
    # install Cattura Platform
    logger.info("Installing Cattura Platform")
    context.install(CATTURA_PLATFORM_PACKAGE, dpkg_options=["--force-confdef", "--force-confold"])
    
    # install backend extras
    (add_backend, remove_backend) = resolve_add_remove_features(
        available_features = options["backend"],
        selected_features = context.config.backend,
        default_features = defaults["backend"]
    )
    
    logger.info("Installing Backend Packages: {}".format(", ".join([package["title"] for package in add_backend])))
    context.install(*[package["packages"] for package in add_backend])
    logger.info("Removing Backend Packages: {}".format(", ".join([package["title"] for package in remove_backend])))
    context.remove(*[package["packages"] for package in remove_backend])