import os
import logging

from ..context import Context

logger = logging.getLogger(__name__)

from ..registration import REPOS, get_distribution_name
from ..commands import chroot, bash

def add_repo_key (context, repo_key):
    context.call_privileged(chroot(context.config.target, bash("echo '{}' | apt-key add -".format(repo_key))))

def __call__ (config):
    context = Context(config, logger)
    needs_update = False
    
    for key, value in REPOS.items():
        if key == "capturecast":
            continue
        
        extra_repo_apt_file = context.get_path(value["file"])
        if not os.path.isfile(extra_repo_apt_file):
            logger.info("Adding Cattura {} repository to apt".format(key))
            repo_path = value.get("path", "")
            repo_component = value.get("component", "")
            repo_distribution = value.get("distribution", get_distribution_name())
            repo_url = value["url"].format(distribution=repo_distribution)

            full_repo_line = "deb {}".format(repo_url)
            if repo_path:
                full_repo_line = "{} {}".format(full_repo_line, repo_path)
            elif repo_distribution:
                full_repo_line = "{} {}".format(full_repo_line, repo_distribution)
            
            if repo_component:
                full_repo_line = "{} {}".format(full_repo_line, repo_component)

            repo_key = value.get("key", "")
            if repo_key:
                add_repo_key(context, repo_key)

            context.write_privileged(full_repo_line, extra_repo_apt_file)
            needs_update = True
        else:
            logger.info("Not adding Cattura {} repository since it already exists".format(key))
    
    # update apt-get
    if needs_update:
        context.apt_update()