import logging

from ..context import Context
from ..capturecast import CaptureCast

logger = logging.getLogger(__name__)

def __call__ (config):
    context = Context(config, logger)
    capturecast = CaptureCast(context)
    
    if capturecast.is_running():
        if context.ask_yesno("CaptureCast is currently running. It must be stopped before proceeding. Stop it now?"):
            capturecast.stop()
        else:
            raise Exception("CaptureCast is running and was not stopped")
    
    database = capturecast.get_database()
    if database:
        logger.info("Removing Cattura data from database")
        database.drop()
    
    logger.info("Removing Cattura data from filesystem")
    context.call_privileged(["rm", "-rf", context.get_path(context.config.cattura_path, "storage")])