import logging
import os

from ..context import Context

logger = logging.getLogger(__name__)

APT_FILE_PATTERN = "/etc/apt/sources.list.d/{}.list"
LEGACY_APT_REPOS = {
    "google-chrome": "Google Chrome",
    "webupd8team-java": "WebUpd8 JDK PPA",
    "webupd8team-ubuntu-java-xenial": "WebUpd8 JDK PPA (Xenial)",
    "webupd8team-java-trusty": "WebUpd8 JDK PPA (Trusty)",
    "teamviewer": "TeamViewer 13"
}

def __call__ (config):
    context = Context(config, logger)
    
    logger.info("Removing legacy apt repositories")
    needs_apt_update = False
    for key, value in LEGACY_APT_REPOS.items():
        apt_file_path = context.get_path(APT_FILE_PATTERN.format(key))
        if os.path.exists(apt_file_path):
            logger.info("Removing legacy repository: {}".format(value))
            context.call_privileged(["rm", apt_file_path])
            needs_apt_update = True
    
    # update apt-get
    if needs_apt_update:
        context.apt_update()